@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "1c1bd444a9265fc92bb277e61442baa8e03145a7",
-  "branchName": "release",
-  "buildTime": "Fri, 04 Nov 2022 09:26:48 GMT",
-  "buildVersion": "5.1.138",
+  "commitId": "253cec94b36683a52e7e9c7cc85358902e874c51",
+  "branchName": "release-client-5.12.x",
+  "buildTime": "Mon, 21 Nov 2022 06:45:42 GMT",
+  "buildVersion": "5.1.148",
   "css": [
     "@zoom/client-scheduler/static/css/chunk-vendors.7f57ae19.css",
     "@zoom/client-scheduler/static/css/index.e12145da.css"
   ],
   "js": [
-    "@zoom/client-scheduler/static/js/chunk-vendors.c9bce98f.js",
-    "@zoom/client-scheduler/static/js/index.1ffda21c.js"
+    "@zoom/client-scheduler/static/js/chunk-vendors.4c3b92cb.js",
+    "@zoom/client-scheduler/static/js/index.35f877a9.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
